==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/hr/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Potvrda opcije brisanja brisanja',
  'bulk_delete_help'	=> 'U nastavku pregledajte materijale za skupnu brisanje. Nakon što se izbrisati, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima kojima su trenutačno dodijeljeni.',
  'bulk_delete_warn'	=> 'Izbrisat ćete: asset_count assets.',
	'bulk_update'		=> 'Skupna aktivacija ažuriranja',
	'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više imovine odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
	'bulk_update_warn'	=> 'Namjeravate urediti svojstva: imovine asset_count.',
    'checkedout_to'		=> 'Provjereno',
    'checkout_date'		=> 'Datum kupnje',
    'checkin_date'		=> 'Datum čekanja',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Trošak nabave',
    'create'			=> 'Izrada alata',
    'date'				=> 'Datum kupnje',
    'depreciation'	    => 'deprecijacija',
    'depreciates_on'	=> 'Deprecira On',
    'default_location'	=> 'Zadana lokacija',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopu',
    'expected_checkin'  => 'Očekivani datum provjere',
    'expires'			=> 'istječe',
    'fully_depreciated'	=> 'Potpuno se amortizira',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj materijal, odaberite "Spreman za implementaciju" iz gore navedenog popisa statusa.',
    'mac_address'		=> 'Mac adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'mjeseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Bilješke',
    'order'				=> 'Broj narudžbe',
    'qr'				=> 'QR kod',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj materijal',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serijski',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje aktiva',
    'warranty'			=> 'garancija',
		'warranty_expires'		=> 'Jamstvo istječe',
    'years'				=> 'godina',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/hr/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrda opcije brisanja brisanja',
  'bulk_delete_help'	=> 'U nastavku pregledajte materijale za skupnu brisanje. Nakon što se izbrisati, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima kojima su trenutačno dodijeljeni.',
  'bulk_delete_warn'	=> 'Izbrisat ćete: asset_count assets.',
    'bulk_update'		=> 'Skupna aktivacija ažuriranja',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više imovine odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'bulk_update_warn'	=> 'Namjeravate urediti svojstva: imovine asset_count.',
    'checkedout_to'		=> 'Provjereno',
    'checkout_date'		=> 'Datum kupnje',
    'checkin_date'		=> 'Datum čekanja',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Trošak nabave',
    'create'			=> 'Izrada alata',
    'date'				=> 'Datum kupnje',
    'depreciation'	    => 'deprecijacija',
    'depreciates_on'	=> 'Deprecira On',
    'default_location'	=> 'Zadana lokacija',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopu',
    'expected_checkin'  => 'Očekivani datum provjere',
    'expires'			=> 'istječe',
    'fully_depreciated'	=> 'Potpuno se amortizira',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj materijal, odaberite "Spreman za implementaciju" iz gore navedenog popisa statusa.',
    'mac_address'		=> 'Mac adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'mjeseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Bilješke',
    'order'				=> 'Broj narudžbe',
    'qr'				=> 'QR kod',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj materijal',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serijski',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje aktiva',
    'warranty'			=> 'garancija',
        'warranty_expires'		=> 'Jamstvo istječe',
    'years'				=> 'godina',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
